==> hslua-cli-1.4.1-65-x86_64.pkg.tar.zst: usr/share/haskell/register/hslua-cli.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-cli
version:              1.4.1
visibility:           public
id:                   hslua-cli-1.4.1-2vlKhdnRKud4mgYMboWS7t
key:                  hslua-cli-1.4.1-2vlKhdnRKud4mgYMboWS7t
license:              MIT
copyright:            © 2022-2023 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Command-line interface for Lua
description:
    Provides an embeddable command-line interface for Lua.
    The interface is compatible with the standard Lua
    interpreter, i.e., the `lua` executable provided in a
    default Lua installation.

category:             Foreign
abi:                  c83d6fe95a7ccacd937a64f3825cc2a7
exposed:              True
exposed-modules:      HsLua.CLI
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-cli-1.4.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-cli-1.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hslua-cli
hs-libraries:         HShslua-cli-1.4.1-2vlKhdnRKud4mgYMboWS7t
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    hslua-core-2.3.1-IxMDsbytAuM1HrMVpwgrKy
    hslua-marshalling-2.3.1-4MEdFsZjEWq2yQXjBPkQrB
    hslua-repl-0.1.2-9ot5Yv2Bu4tK29gRc0cGHc
    lua-2.3.3-EDa4xxl8xsiFVlSKgLZzK1 text-1.2.5.0 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/hslua-cli/html/hslua-cli.haddock
haddock-html:         /usr/share/doc/hslua-cli/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hslua-cli-1.4.1-67-x86_64.pkg.tar.zst: usr/share/haskell/register/hslua-cli.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-cli
version:              1.4.1
visibility:           public
id:                   hslua-cli-1.4.1-7j78Uu7o98REA7AOeoLPD
key:                  hslua-cli-1.4.1-7j78Uu7o98REA7AOeoLPD
license:              MIT
copyright:            © 2022-2023 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Command-line interface for Lua
description:
    Provides an embeddable command-line interface for Lua.
    The interface is compatible with the standard Lua
    interpreter, i.e., the `lua` executable provided in a
    default Lua installation.

category:             Foreign
abi:                  8db3c39c7652f108df4b40d515ae328b
exposed:              True
exposed-modules:      HsLua.CLI
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-cli-1.4.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-cli-1.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hslua-cli
hs-libraries:         HShslua-cli-1.4.1-7j78Uu7o98REA7AOeoLPD
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    hslua-core-2.3.1-6X5SDtWMvCzIQDTWRzfuxN
    hslua-marshalling-2.3.1-9rw6upwJeCn7H9tXrF7IS3
    hslua-repl-0.1.2-EmNxccosjF874rwijw4adG
    lua-2.3.3-H0mQnGfojPt660wfaOgvHW text-1.2.5.0 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/hslua-cli/html/hslua-cli.haddock
haddock-html:         /usr/share/doc/hslua-cli/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
